pub struct PhaseRing { /* private fields */ }Expand description
Defines a ring of phases in a traffic rule system.
A phase ring represents a sequence of phases that a traffic control system cycles through.
Implementations
Sourceimpl PhaseRing
impl PhaseRing
Sourcepub fn phases(&self) -> Vec<String>
pub fn phases(&self) -> Vec<String>
Returns the ids of all Phases in the PhaseRing.
Returns
A vector of strings representing the ids of all Phases in the PhaseRing.
Sourcepub fn get_next_phases(
&self,
id: &String,
) -> Result<Vec<NextPhase>, MaliputError>
pub fn get_next_phases( &self, id: &String, ) -> Result<Vec<NextPhase>, MaliputError>