pub struct TrafficSignValue {
pub value: f64,
pub unit: TrafficSignValueUnit,
}Expand description
Holds a numeric value and its associated unit for a traffic sign.
Fields
value: f64unit: TrafficSignValueUnitTrait Implementations
Sourceimpl Clone for TrafficSignValue
impl Clone for TrafficSignValue
Sourcefn clone(&self) -> TrafficSignValue
fn clone(&self) -> TrafficSignValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TrafficSignValue
Sourceimpl Debug for TrafficSignValue
impl Debug for TrafficSignValue
Sourceimpl PartialEq for TrafficSignValue
impl PartialEq for TrafficSignValue
Sourcefn eq(&self, other: &TrafficSignValue) -> bool
fn eq(&self, other: &TrafficSignValue) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TrafficSignValue