Modules
- rules
- stack_
height - The pass that tries to make stack overflows deterministic, by introducing an upper bound of the stack size.
Structs
- Delete
Transaction - Delete transaction.
- Entry
- Reference counting, link-handling object.
- Entry
Ref - Reference to the entry in the rerence list.
- Module
- Module
- RefList
- List that tracks references and indices.
- Target
Symbols
Enums
Functions
- build
- externalize
- externalize_
mem - graph_
generate - Generate xwasm
Module - graph_
parse - New module from xwasm
Module - inject_
gas_ counter - Injects gas counter.
- inject_
runtime_ type - optimize
- pack_
instance - If a pxwasm module has an exported function matching “create” symbol we want to pack it into “constructor”.
raw_moduleis the actual contract codector_moduleis the constructor which should returnraw_module - shrink_
unknown_ stack - underscore_
funcs - ununderscore_
funcs